#ifndef __CHM_ENGINE_H__
#define __CHM_ENGINE_H__
//------------------------------------------------------------------------
// Copyright (C) 1997-2005 iNTERFACEWARE Inc.  All Rights Reserved
//
// Module: CHMengine
//
// Description:
//
// Engine DLL declarations
//
// Author: Eliot Muir
// Date:   Wed 09/09/1998 
// Revision: $Revision: 1.65 $
//
// Last Edit Date: $Date: 2009-02-25 16:14:47 $
// Source: $Source: /home/cvs/cvsroot/CHM/CHMengine.h,v $
//---------------------------------------------------------------------------

#include "CHMcallbackFunction.h"
#include "CHMdataType.h"

// CHM_DLL_FUNC(CHMresult) code equals zero for success

CHM_DLL_FUNC(CHMgetMachineId)
(
   CHMchar** ppMachineId
);

CHM_DLL_FUNC(CHMengineCreate)
(
   CHMengineHandle* Handle
);

// Extra hidden constructor for CHMengine. See #9748.
CHM_DLL_FUNC(CHMgetCurrentByteIndex)
(
   CHMengineHandle* Handle,
   const char* Key
);

CHM_DLL_FUNC(CHMengineAddRef)
(
   CHMengineHandle Handle
);

CHM_DLL_FUNC(CHMengineRelease)
(
   CHMengineHandle Handle
);

CHM_DLL_FUNC(CHMengineLoad)
(
   CHMengineHandle Handle, 
   const char*     pFileName
);

CHM_DLL_FUNC(CHMengineLoadW)
(
   CHMengineHandle Handle,
   const wchar_t*  pFilename
);  

CHM_DLL_FUNC(CHMengineIsUsingPassthruMapping)
(
    CHMengineHandle Handle, 
    CHMboolean*     pResult
);

#ifdef WIN32 //this is for C#
    
CHM_DLL_FUNC(CHMengineLoadFromMemory)
(
   CHMengineHandle Handle, 
   wchar_t* BinaryData
);

#endif

CHM_DLL_FUNC(CHMengineParseMessageA)
(
  CHMengineHandle Handle,
  const char*     pFlatWire, 
  size_t*         MessageIndex,  
  CHMtableHandle  ResultTable
);

CHM_DLL_FUNC(CHMengineParseMessageW)
(
   CHMengineHandle Handle,
   const wchar_t*  pFlatWire,
   size_t*         MessageIndex,
   CHMtableHandle  ResultHandle
);

// The MessageTable must have been setup by createEmptyTable 
CHM_DLL_FUNC(CHMengineGenerateMessage)
(
    CHMengineHandle Handle,
    const char**    pFlatWire, 
    size_t          MessageIndex,
    CHMtableHandle  MessageTable
);

CHM_DLL_FUNC(CHMengineGenerateMessageW)
(
    CHMengineHandle Handle,
    const wchar_t** pFlatWire, 
    size_t          MessageIndex,
    CHMtableHandle  MessageTable
);



// This function is used to generate an empty table for a message.
CHM_DLL_FUNC(CHMengineCreateEmptyMessageTable)
(
   CHMengineHandle Handle,
   size_t          MessageIndex, 
   CHMtableHandle  EmptyTable
);
   
// These methods provide version information.

CHM_DLL_FUNC(CHMengineGetMinorVersion)
(
   CHMengineHandle Handle, 
   size_t*         Version
);

CHM_DLL_FUNC(CHMengineGetMajorVersion)
(
   CHMengineHandle Handle,
   size_t*         Version
);

CHM_DLL_FUNC(CHMengineGetBuildNumber)
(
   CHMengineHandle Handle,
   size_t*         BuildNumber
);

CHM_DLL_FUNC(CHMengineGetVersionString)
(
   CHMengineHandle Handle,
   const char**    ppVersionString
);

CHM_DLL_FUNC(CHMengineGetSourceDateTime)
(
   const char**    ppSourceDateTime
);

CHM_DLL_FUNC(CHMengineGetSourceTag)
(
   const char**    ppSourceTag
);

CHM_DLL_FUNC(CHMengineGetBuildId)
(
   const char**    ppBuildId
);

CHM_DLL_FUNC(CHMengineSetRejectBadSegmentGrammarFlag)
(
   CHMengineHandle Handle,
   CHMboolean      Flag
);

CHM_DLL_FUNC(CHMengineGetRejectBadSegmentGrammarFlag)
(
   CHMengineHandle Handle,
   size_t*         pFlag
);

CHM_DLL_FUNC(CHMengineCountOfMessage)
(
   CHMengineHandle Handle,
   size_t*         CountOfMessage
);

CHM_DLL_FUNC(CHMengineMessageName)
(
   CHMengineHandle Handle,
   size_t          MessageIndex,
   const char**    ppMessageName
);

CHM_DLL_FUNC(CHMengineMessageNameW)
(
   CHMengineHandle Handle,
   size_t          MessageIndex,
   const wchar_t** ppMessageName
);

CHM_DLL_FUNC(CHMengineResetPythonEngine)
(
   CHMengineHandle Handle
);

CHM_DLL_FUNC(CHMengineSimpleParse)
(
   CHMengineHandle             Handle,
   const char*                 Flatwire,
   CHMuntypedMessageTreeHandle TreeHandle,
   size_t*                     pMessageIndex
);

CHM_DLL_FUNC(CHMengineConfig)
(
   CHMengineHandle   Handle,
   CHMconfigHandle*  pConfigHandle
);

CHM_DLL_FUNC(CHMengineSetLogCallBack)
(
   CHMengineHandle  Handle,
   CHMlogProc LogProc
);

CHM_DLL_FUNC(CHMengineSetLogCallBackPerEngine)
(
   CHMengineHandle  Handle,
   CHMengineStubHandle StubHandle,
   CHMengineLogProc LogProc
);

CHM_DLL_FUNC(CHMengineSetLogCallBackW)
(
   CHMengineHandle Handle,
   CHMwideLogProc  LogProc
);

CHM_DLL_FUNC(CHMengineCountOfSegment)
(
   CHMengineHandle Handle,
   size_t*         pCountOfSegment
);

CHM_DLL_FUNC(CHMengineGetMessage)
(
   CHMengineHandle   Handle,
   size_t            MessageIndex,
   CHMmessageHandle* pMessageHandle
);

CHM_DLL_FUNC(CHMengineMessageByName)
(
   CHMengineHandle Handle,
   const char*     pMessageName,
   size_t*         pMessageIndex
);    

CHM_DLL_FUNC(CHMengineGetAckMessageIndex)
(
   CHMengineHandle Handle,
   size_t*         pMessageIndex
);

CHM_DLL_FUNC(CHMengineSetAckMessageIndex)
(
   CHMengineHandle Handle,
   size_t          MessageIndex
);

CHM_DLL_FUNC(CHMengineTransformMessage)
(
   CHMengineHandle   Handle,
   const char*       InMessage,
   size_t            InConfigIndex,
   size_t            OutConfigIndex,
   const char**      OutMessage,
   size_t*           MessageIndex,
   size_t            IsDebugging
);

CHM_DLL_FUNC(CHMengineTransformMessageW)
(
   CHMengineHandle   Handle,
   const wchar_t*    InMessage,
   size_t            InConfigIndex,
   size_t            OutConfigIndex,
   const wchar_t**   OutMessage,
   size_t*           MessageIndex,
   size_t            IsDebugging
);

CHM_DLL_FUNC(CHMengineCountOfConfig)
(
   CHMengineHandle Handle,
   size_t*         pCountOfConfig
);

CHM_DLL_FUNC(CHMengineConfigName)
(
   CHMengineHandle Handle,
   size_t          ConfigIndex,
   const char**    pConfigName
);

CHM_DLL_FUNC(CHMengineDump)
(
   CHMengineHandle Handle,
   char**      ppDumpString
);

CHM_DLL_FUNC(CHMengineFreeBuffer)
(
   char** ppString
);

CHM_DLL_FUNC(CHMengineDumpW)
(
   CHMengineHandle Handle,
   wchar_t**      ppDumpString
);

CHM_DLL_FUNC(CHMengineFreeBufferW)
(
   wchar_t** ppString
);

CHM_DLL_FUNC(CHMengineSetIncomingConfigIndex)
(
   CHMengineHandle Handle,
   size_t          Index
);

CHM_DLL_FUNC(CHMengineGetIncomingConfigIndex)
(
   CHMengineHandle Handle,
   size_t*         pIndex
);

CHM_DLL_FUNC(CHMengineSetOutgoingConfigIndex)
(
   CHMengineHandle Handle,
   size_t          Index
);

CHM_DLL_FUNC(CHMengineGetOutgoingConfigIndex)
(
   CHMengineHandle Handle,
   size_t*         pIndex
);

CHM_DLL_FUNC(CHMengineSetCurrentConfig)
(
   CHMengineHandle Handle,
   size_t          Index
);

CHM_DLL_FUNC(CHMengineGetCurrentConfig)
(
   CHMengineHandle Handle,
   size_t*         pIndex
);

CHM_DLL_FUNC(CHMengineGetIgnoreMessageIndex)
(
   CHMengineHandle Handle,
   size_t*         pMessageIndex
);


CHM_DLL_FUNC(CHMengineTranslateMessageToXml)
(
   CHMengineHandle Handle,
   const char*     pFlatWire,
   const char**    ppResultXml
);

CHM_DLL_FUNC(CHMengineTranslateXmlToMessage)
(
   CHMengineHandle Handle,
   const char*     pXml,
   const char**    ppResultMessage
);

CHM_DLL_FUNC(CHMengineTranslateMessageToHl7StandardXml)
(
   CHMengineHandle Handle,
   const char*     pFlatWire,
   const char**    ppResultXml
);

CHM_DLL_FUNC(CHMengineTranslateHl7StandardXmlToMessage)
(
   CHMengineHandle Handle,
   const char*     pXml,
   const char**    ppResultMessage 
);

CHM_DLL_FUNC(CHMengineGetCountOfTable)
(
   CHMengineHandle Handle,
   size_t*         pCountOfTable
);

CHM_DLL_FUNC(CHMengineMessageDiff)
(
   CHMengineHandle Handle,
   const char*     Message1,
   const char*     Message2,
   const char**    ppReport,
   CHMuint32*      pErrorCount
);


CHM_DLL_FUNC(CHMengineGetTable)
(
   CHMengineHandle Handle,
   size_t          TableIndex,
   CHMtableHandle* pTableHandle
);

CHM_DLL_FUNC(CHMengineGenerateAckFromMessage)
(
   CHMengineHandle Handle,
   const char*     pOriginalMessage,
   const char**    ppAck
);

CHM_DLL_FUNC(CHMengineGetTibcoSchema)
(
   CHMengineHandle Handle,
   const char*     FileName
);

CHM_DLL_FUNC(CHMengineSetPythonKeyValuePair)
(
   CHMengineHandle Handle,
   const char*     pKey,
   const char*     pValue 
);

CHM_DLL_FUNC(CHMengineExtendPythonLibraryPath)
(
   CHMengineHandle Handle,
   const char*  pPath
);  

CHM_DLL_FUNC(CHMengineCountOfXmlConverter)
(
   CHMengineHandle Handle,
   size_t*     pCount
);

CHM_DLL_FUNC(CHMengineXmlConverterName)
(
   CHMengineHandle Handle,
   size_t     Index,
   const char** ppXmlName
);

CHM_DLL_FUNC(CHMengineXmlConverterNameFromAlias)
(
   CHMengineHandle Handle,
   const char*     pXmlAlias,
   const char**    ppXmlName
);

CHM_DLL_FUNC(CHMengineSetDefaultDatabase)
(
   CHMengineHandle Handle,
   const char* pAPI, 
   const char* pName,
   const char* pUserName,
   const char* pPassword
);

CHM_DLL_FUNC(CHMengineMakePrintable)
(
   CHMengineHandle Handle,
   const char* pInput,
   const char* pReplacement,
   const char** pOutput
);

CHM_DLL_FUNC(CHMengineMakeParseable)
(
   CHMengineHandle Handle,
   const char* pInput,
   const char* pTarget,
   const char** pOutput
);

CHM_DLL_FUNC(CHMengineSetCreateDatabaseFp)
(
   CHMengineHandle Handle,
   void* pFp
);

CHM_DLL_FUNC(CHMengineSetCreateDatabaseFpContext)
(
   CHMengineHandle Handle,
   void* pContext
);

#endif // end of defensive include
