#ifndef __CHM_LLP_CONNECTION_H__
#define __CHM_LLP_CONNECTION_H__
//--------------------------------------------------------------------------
// Copyright (C) 1997-2009 iNTERFACEWARE Inc. All Rights Reserved.
//
// Class: CHMllpConnection
//
// Description:
//
// Class interface definition.
//
// This file is automatically generated.
// DO NOT EDIT.
//
// Author: codegen2
// Date:   Tuesday, August 11th, 2009 @ 05:32:24 PM
// Revision: $Revision: 1.3 $
//
// Last Edit Date: $Date: 2009-08-11 21:35:20 $
// Source: $Source: /home/cvs/cvsroot/CHM/CHMllpConnection.h,v $
//--------------------------------------------------------------------------

#include <CHM/CHMminimumInclude.h>

#ifndef __CHM_CONNECTION_HANDLE_H__
#define __CHM_CONNECTION_HANDLE_H__
typedef void* CHMconnectionHandle;
#endif


/**
 * This object is passed as an argument for many of the events of the CHMllpServer 
 * object.
 * 
 * This class provides methods to interact with each discrete client connection.
 * 
 * See http://www.interfaceware.com/manual/network_components.html for more 
 * information.
 * 
 */
class CHMllpConnection
{
public:
   /** Constructor */
   CHMllpConnection();
   CHMllpConnection(const CHMllpConnection& Orig);
   CHMllpConnection(CHMconnectionHandle Handle);
   
   /** Destructor */
   virtual ~CHMllpConnection();
   
   /** Assignment operator */
   CHMllpConnection& operator=(const CHMllpConnection& Orig);
   
   /** This method is part of the internal implementation of this class and should not be called. */
   CHMconnectionHandle GetHandle() const { return Handle; }
   
   
   /**
    *  This property will resolve the remoteIpAddress to the host name if possible 
    * using the operating system. Sometimes no host name resolution will be possible 
    * at which point this function will return 'unknown'. 
    * 
    * For the first time this method is called, it blocks until the name is resolved. 
    * This means that if you make the call in the context of your message loop your 
    * application will appear to freeze for a few seconds. 
    * 
    * Subsequent calls will return immediately with a cached value. 
    * 
    *  For more advanced functionality you may wish to use other facilities to resolve 
    * the host name outside of the functionality offered here. 
    * 
    */
   const char* RemoteHostName() const;
   
   
   /**
    * A unique ID for all connection objects.
    * 
    * This ID is generated sequentially (i.e. 0, 1, 2, 3, etc.) for all connections 
    * received from a LlpServer, beginning at 0 when the application starts. The ID is 
    * globally unique and will allow users to identify connections from the same 
    * client, or connections from different clients.
    * 
    */
   CHMint32 Id() const;
   
   
   /**
    * The IP address of the remote host in host byte order.
    * 
    * Consider using CHMllpConnection#RemoteIpAddressAsString instead for a more 
    * usable format.
    * 
    */
   CHMint32 RemoteIpAddress() const;
   
   
   /**
    * The IP address of the remote host as a string.
    * 
    * See also CHMllpConnection#RemoteIpAddress.
    * 
    */
   const char* RemoteIpAddressAsString() const;
   
   
   /**
    * Send a message to the client, prefixed and postfixed by the current 
    * CHMllpServer#HeaderBlock and CHMllpServer#TrailerBlock characters.
    * 
    * The data is not guaranteed to be received after this function is called. All 
    * data is buffered internally; completion of this call does not signify reception 
    * of data.
    * 
    * Function requires a running message loop (see CHMllpServer#RunMessageLoop).
    * 
    * Blocking: Function does not block. 
    * <br>Events: If an error occurs during the send operation, an 
    * CHMllpServer#OnClientErrorReceived event results, containing the error message 
    * indicating why the send attempt has failed.
    * 
    * @param Message HL7 message to send to a client connection in plain string 
    * format.
    */
   void TransmitMessage(const char* Message);
   
   
   /**
    * Attempt to gracefully disconnect from the server.
    * 
    * A graceful disconnect implies a shutdown to the write end of the connection, and 
    * reading all data until the peer issues a close to its write end.
    * 
    * Note that the peer may not actually close the write end of its connection 
    * (although this is rare), which results in the connection never receiving the 
    * close event to signify that the connection is closed. In this situation, it is 
    * recommended that CHMllpConnection#HardDisconnect be called to close the 
    * connection.
    * 
    * Function requires a running message loop (see CHMllpServer#RunMessageLoop).
    * 
    * Blocking: Function does not block. 
    * <br>Events: If the close succeeds (the peer closes the connection), a 
    * CHMllpServer#OnClientDisconnected event results. If an error occurs during the 
    * close operation, an CHMllpServer#OnClientErrorReceived event results, containing 
    * the error message indicating why the close attempt failed.
    * 
    */
   void Disconnect();
   
   
   /**
    * Ungracefully disconnect without doing TCP/IP handshaking with the server.
    * 
    * If there is data pending on the network buffer to be sent, the peer will receive 
    * a reset on the connection if it attempts to read or write to the connection.
    * 
    * Blocking: Function blocks; upon returning, the connection is closed. 
    * <br>Events: None.
    * 
    */
   void HardDisconnect();
   
   
private:
   CHMconnectionHandle Handle;
};

#endif // end of defensive include
