#ifndef __CHM_OUTPUT_LOG_H__
#define __CHM_OUTPUT_LOG_H__
//---------------------------------------------------------------------------
// Copyright (C) 1997-2007 iNTERFACEWARE Inc.  All Rights Reserved
//
// Module: CHMoutputLog
//
// Author: Greg Norman
// Revision: $Revision: 1.11 $
//
// Last Edit Date: $Date: 2007-02-12 21:35:42 $
// Source: $Source: /home/cvs/cvsroot/CHM/CHMoutputLog.h,v $
//---------------------------------------------------------------------------
#include <CHM/CHMminimumInclude.h>

/** Abstract class for implementing an output log.
 * This class forms a useful abstract output interface that
 * can be redirected to a number of different outputs by deriving
 * a child class and implementing the OutputLine method.
 */
class CHMoutputLog
{
public:
   /** Constructor. */
   CHMoutputLog() {}
   /** Destructor. */
   virtual ~CHMoutputLog() {}

   // This function is deprecated.
   //
   //void OutputStream(IOstrstream& OutputStream);

      /** Get the format of newlines in the log medium.  
    * Windows edit controls require a different control sequence from standard
    * output for outputting a newline.  This method allows the writer of the
    * child class to specify the newline sequence valid for the log type.
    */
   virtual const CHMchar* NewLine() const;
   
   /** Output a line to the log; must be overridden by the child class. */
   virtual void OutputLine(const CHMchar* Line) = 0;
    
private:
   CHMoutputLog& operator=(const CHMoutputLog& Orig);
   CHMoutputLog(const CHMoutputLog& Orig);
};
#endif // end of defensive include
