//---------------------------------------------------------------------------
//
// Module: CHMparseErrorEnum.h
//
// Description:
//
// This file contains declarations for the enumerations used to
// declare parsing errors in the product.  These are used both in
// the COM and C++ interfaces
//
//---------------------------------------------------------------------------

// Common file with debug macros for use in application
#ifndef __CHM_PARSE_ERROR_ENUM_H__
#define __CHM_PARSE_ERROR_ENUM_H__

// Parse errors - used for errors with parameters
#define CHM_DEF_peRequiredFieldNotPresent      0x00
#define CHM_DEF_peFieldMaxRepeatsExceeded      0x01
#define CHM_DEF_peUnexpectedExtraFields        0x02
#define CHM_DEF_peFieldMaxLengthExceeded       0x03
#define CHM_DEF_peUnexpectedSegment            0x04
#define CHM_DEF_peRequiredSegmentMissing       0x05
#define CHM_DEF_peRequiredSegmentGroupMissing  0x06
#define CHM_DEF_peUnexpectedTrailingSegments   0x07
#define CHM_DEF_peBadEscapeSequence            0x08
#define CHM_DEF_peNoSegmentIdentifier          0x09
#define CHM_DEF_peBadIntegerFormat             0x0A
#define CHM_DEF_peBadDoubleFormat              0x0B
#define CHM_DEF_peBadDateTimeFormat            0x0C 
#define CHM_DEF_peBadEnumFormat                0x0D 
#define CHM_DEF_peRequiredSubFieldNotPresent    0x0F
#define CHM_DEF_peRequiredSubSubFieldNotPresent 0x10

// Exceptions - used as codes in CHMerror
#define CHM_DEF_ecPreCondition         0x80000100
#define CHM_DEF_ecPostCondition        0x80000101
#define CHM_DEF_ecFileExists           0x80000200
#define CHM_DEF_ecFileError            0x80000201
#define CHM_DEF_ecBoundaryError        0x80000300
#define CHM_DEF_ecTableContainsData    0x80000400
#define CHM_DEF_ecSystemError          0x80000500
#define CHM_DEF_ecInvalidDateTime      0x80000600
#define CHM_DEF_ecInvalidRepeatChar    0x80000700
#define CHM_DEF_ecIllegalOperation     0x80000800
#define CHM_DEF_ecWrongDataType        0x80000801
#define CHM_DEF_ecUnknownDataType      0x80000900
#define CHM_DEF_ecSerializationError   0x80001000
#define CHM_DEF_ecMessageTooShort      0x80001100
#define CHM_DEF_ecNoHeaderSegment      0x80001200
#define CHM_DEF_ecNoEncodingCharField  0x80001201
#define CHM_DEF_ecNoHeaderSegmentName  0x80001202
#define CHM_DEF_ecNoSegmentDelimiter   0x80001203
#define CHM_DEF_ecHl7NoFieldDelimiter  0x80001204
#define CHM_DEF_ecSubSubWithoutSub     0x80001205
#define CHM_DEF_ecNonExistentSubTable  0x80001300
#define CHM_DEF_ecNoMessagesLoaded     0x80001400
#define CHM_DEF_ecInterfaceFrozen      0x80001500
#define CHM_DEF_ecInterfaceOutOfDate   0x80001501
#define CHM_DEF_ecNotLicensed          0x80001600
#define CHM_DEF_ecBadEquation          0x80001700
#define CHM_DEF_ecSubscriptOutOfRange  0x80002000

// Parse Results - set of exception codes from the HL7engine
#define CHM_DEF_prUnknownMessage           0x80002001
#define CHM_DEF_prUnknownSegment           0x80002002
#define CHM_DEF_prBadSegmentGrammar        0x80002003
#define CHM_DEF_prBadMessageGrammar        0x80002004
#define CHM_DEF_prNoSegmentIdentifier      0x80002005
#define CHM_DEF_prValidationRuleFailed     0x80002006
#define CHM_DEF_prUnexpectedSegment        0x80002007
#define CHM_DEF_prExpectedSegmentMissing   0x80002008
#define CHM_DEF_prMaxSegmentRepeatExceeded 0x80002009
#define CHM_DEF_prMaxSegmentGroupRepeatExceeded 0x80002010

#endif  // end of defensive include
