#ifndef __CHM_TABLE__
#define __CHM_TABLE__

//---------------------------------------------------------------------------
// Module: CHMtable
//
// Description:
//
// This is a thin interface class to the real underlying table class
// This approach is taken to hide the implementation of the HL7 Chameleon
// library from the client application - thus enabling easy upgrading without
// recompilation or relinking.
//
//---------------------------------------------------------------------------

#include <CHM/CHMminCInclude.h>
#include <CHM/CHMdataType.h>

CHM_DLL_FUNC(CHMtableCreate)
(
   CHMtableHandle* Handle
);

CHM_DLL_FUNC(CHMtableAddRef)
(
   CHMtableHandle Handle
);

CHM_DLL_FUNC(CHMtableRelease)
(
   CHMtableHandle Handle
);

CHM_DLL_FUNC(CHMtableName)
(
   CHMtableHandle  Handle,
   char**       pName
);

CHM_DLL_FUNC(CHMtableGetTableGrammar)
(
    CHMtableHandle Handle,
    CHMtableGrammarHandle* ppTableGrammar 
);

CHM_DLL_FUNC(CHMtableSubTable)
(
   CHMtableHandle  Handle,
   size_t          RowIndex,
   size_t          TableIndex,
   CHMtableHandle* pSubTable
);

CHM_DLL_FUNC(CHMtableGetSubTableIndex)
(
    CHMtableHandle Handle,
    const char*    pSubTableName,
    size_t*        pSubTableIndex
);

CHM_DLL_FUNC(CHMtableCountOfColumn)
(
   CHMtableHandle Handle,
   size_t*        Count
);

CHM_DLL_FUNC(CHMtableCountOfRow)
(
   CHMtableHandle Handle,
   size_t*        Count
);

CHM_DLL_FUNC(CHMtableCountOfSubTable)
(
   CHMtableHandle Handle,
   size_t*        Count
);

CHM_DLL_FUNC(CHMtableColumnType)
(
   CHMtableHandle Handle,
   size_t         ColumnIndex,
   CHMdataType*   pDataType
);

CHM_DLL_FUNC(CHMtableColumnName)
(
   CHMtableHandle Handle,
   size_t         ColumnIndex,
   const char**   ppColumnName
);

CHM_DLL_FUNC(CHMtableColumnIndex)
(
   CHMtableHandle Handle,
   const char*    pColumnName,
   size_t*        pColumnIndex
);

CHM_DLL_FUNC(CHMtableIsNull)
(
   CHMtableHandle Handle,
   size_t         ColumnIndex,
   size_t         RowIndex,
   CHMboolean*    pIsNull
);

CHM_DLL_FUNC(CHMtableState)
(
   CHMtableHandle Handle,
   size_t         ColumnIndex,
   size_t         RowIndex,
   size_t*        pState
);

CHM_DLL_FUNC(CHMtableSetNull)
(
   CHMtableHandle Handle,
   size_t         ColumnIndex,
   size_t         RowIndex
);

CHM_DLL_FUNC(CHMtableGetStringA)
(
   CHMtableHandle  Handle,
   size_t          ColumnIndex,
   size_t          RowIndex,
   const char**    pString
);

CHM_DLL_FUNC(CHMtableGetStringW)
(
   CHMtableHandle  Handle,
   size_t          ColumnIndex,
   size_t          RowIndex,
   const wchar_t** pString
);

CHM_DLL_FUNC(CHMtableGetDouble)
(
   CHMtableHandle  Handle,
   size_t          ColumnIndex,
   size_t          RowIndex,
   double*         pValue
);

CHM_DLL_FUNC(CHMtableGetInteger)
(
   CHMtableHandle  Handle,
   size_t          ColumnIndex,
   size_t          RowIndex,
   long*           pInteger
);
   
CHM_DLL_FUNC(CHMtableGetDateTime)
(
   CHMtableHandle     Handle,
   size_t             ColumnIndex,
   size_t             RowIndex,
   CHMdateTimeHandle* pDateTime
);

CHM_DLL_FUNC(CHMtableSetStringA)
(
   CHMtableHandle Handle,
   size_t         ColumnIndex,
   size_t         RowIndex,
   const char*    Value
);

CHM_DLL_FUNC(CHMtableSetStringW)
(
   CHMtableHandle Handle,
   size_t         ColumnIndex,
   size_t         RowIndex,
   const wchar_t* Value
);

CHM_DLL_FUNC(CHMtableSetDouble)
(
   CHMtableHandle Handle,
   size_t         ColumnIndex,
   size_t         RowIndex,
   double         Value
);

CHM_DLL_FUNC(CHMtableSetInteger)
(
   CHMtableHandle Handle,
   size_t         ColumnIndex,
   size_t         RowIndex,
   long           Value
);

CHM_DLL_FUNC(CHMtableSetDateTime)
(
   CHMtableHandle    Handle,
   size_t            ColumnIndex,
   size_t            RowIndex,
   CHMdateTimeHandle Value
);

CHM_DLL_FUNC(CHMtableAddRow)
(
   CHMtableHandle    Handle
);

// user must free buffer from the dump function
// use the free function below.
CHM_DLL_FUNC(CHMtableDump)
(
   CHMtableHandle Handle,
   char**         ppDumpString
);

CHM_DLL_FUNC(CHMtableDumpW)
(
   CHMtableHandle Handle,
   wchar_t**      ppDumpString
);

CHM_DLL_FUNC(CHMtableFreeBuffer)
(
   char** ppString
);

CHM_DLL_FUNC(CHMtableFreeBufferW)
(
   wchar_t** ppString
);

CHM_DLL_FUNC(CHMtableGetColumnIsKey)
(
   CHMtableHandle Handle,
   size_t ColumnIndex,
   size_t* pIsKey
);

CHM_DLL_FUNC(CHMtableGetKeyColumnIndex)
(
   CHMtableHandle Handle,
   size_t*        pKeyColumnIndex
);

CHM_DLL_FUNC(CHMtableSetKeyColumnIndex)
(
   CHMtableHandle Handle,
   size_t         KeyColumnIndex
);

#endif // end of defensive include
