#ifndef __CHM_TABLE_ROW_H_
#define __CHM_TABLE_ROW_H_
//---------------------------------------------------------------------------
// Copyright (C) 1997-2007 iNTERFACEWARE Inc.  All Rights Reserved
//
// Module: CHMtableRow
//
// Author: Greg Norman
// Revision: $Revision: 1.9 $
//
// Last Edit Date: $Date: 2007-02-12 21:35:42 $
// Source: $Source: /home/cvs/cvsroot/CHM/CHMtableRow.h,v $
//---------------------------------------------------------------------------
#include <CHM/CHMminimumInclude.h>

class CHMtableRowPrivate;
class CHMtable;

/** Table row class.
 * This class is used as the parent for each custom
 * generated table row class.
 */
class CHMtableRow
{
public:
   /** Construct a table row assigned to CHMtable \c pTable at row \c RowIndex. */
   CHMtableRow(const CHMtable* pTable, size_t RowIndex);
   
   /** Destructor. */
   virtual ~CHMtableRow();

   /** Get the count of subtables of \c this row. */
   size_t CountOfSubTable() const;

   /** Get the row index for \c this row. */
   size_t RowIndex() const;
   
   /** Get a const pointer to a subtable of \c this row. */
   const CHMtable* SubTable(size_t SubTableIndex) const;
   
   /** Get a non-const pointer to a subtable of \c this row. */
   CHMtable* SubTable(size_t SubTableIndex);

   /** Get the handle to the underlying table object in Chameleon.
   * This is part of the internal implementation of Chameleon and should not be called. */
   CHMtableHandle TableHandle() const;
   
private:
   CHMtableRowPrivate* pMember;
   CHMtableRow(const CHMtableRow& Orig);             // not allowed
   CHMtableRow& operator=(const CHMtableRow& Orig);  // not allowed
};

#endif // end of defensive include
