#ifndef __CHM_TRANSPORT_H__
#define __CHM_TRANSPORT_H__

//---------------------------------------------------------------------------
// Copyright (C) 1997-2007 iNTERFACEWARE Inc.  All Rights Reserved
//
// Module: CHMtransport
//
// Author: Greg Norman
// Revision: $Revision: 1.8 $
//
// Last Edit Date: $Date: 2007-02-12 21:35:42 $
// Source: $Source: /home/cvs/cvsroot/CHM/CHMtransport.h,v $
//---------------------------------------------------------------------------
#include <CHM/CHMminimumInclude.h>
class CHMstring;
class CHMengine;
class CHMwrapper;
class CHMoutputLog;

/** Abstract interface class for message transport.
 * This is a pure virtual class which forms the interface
 * to the transport layer.  Sub-classes of this can implement
 * various types of transports whether they be TCP/IP sockets,
 * serial links, etc. 
 *
 * \deprecated New applications should use CHMllpConnection.
 * */
class CHMtransport
{
public:
   /** Constructor. */
   CHMtransport();
   
   /** Destructor. */
   virtual ~CHMtransport();

   /** Get the CHMengine object associated with this CHMtransport class. */
   CHMengine* Engine()                { return m_pEngine; }

   /** Get the CHMoutputLog object associated with the CHMengine object that is associated with \c this CHMtransport class. */ 
   CHMoutputLog* Log();

   /** OnError event.
    * This event may be invoked when an error occurs.
    **/
   virtual void OnError(size_t Code, const CHMchar* Description);
      
   /** Send a response message.
    * This method is called by the CHMwrapper class to
    * send the response back to the counter party at \c TransportIndex.  It should
    * be overridden in the child class to provide an implementation.
    */
   virtual void SendResponseMessage(const CHMstring& MessageData,
                                    size_t TransportIndex)=0; 
                                    
   /** Assign the CHMengine object \c pEngine to \c this CHMtransport class.
    * The CHMtransport class <b>does not</b> take ownership of the engine.
    */
   void SetEngine(CHMengine* pEngine) { m_pEngine = pEngine; }
   
   /** Get the CHMwrapper object associated with the CHMengine object that is associated with \c this CHMtransport class.
    * The CHMwrapper object is responsible for implementing the wrapping
    * protocol associated with this class */
   CHMwrapper* Wrapper();

private:
   CHMengine*   m_pEngine;
   // not allowed
   CHMtransport(const CHMtransport& Orig);
   CHMtransport& operator=(const CHMtransport& Orig);
};

#endif // end of defensive include
