#ifndef __NET_DLL_H__
#define __NET_DLL_H__

// This is a private implementation API.  Customers should
// not use it directly.

#include <CHM/CHMdataType.h>
#include <CHM/CHMminCInclude.h>

#ifdef WIN32
#   define CHM_STD_CALL __stdcall
#else
#   define CHM_STD_CALL
#endif

//Server API
typedef void* NETserverHandle;
typedef void* NETconnectionHandle;
typedef void* NETuserHandle;

typedef void (CHM_STD_CALL *NETserverOnErrorCallback)
( 
    NETuserHandle UserHandle, 
    NETserverHandle ServerHandle, 
    int ErrorId, 
    const char* pErrorMessage 
);

typedef void (CHM_STD_CALL *NETserverOnNewConnectionCallback)
( 
   NETuserHandle UserHandle, 
   NETserverHandle ServerHandle, 
   NETconnectionHandle TransportId,
   NETuserHandle* pConnectionUserHAndle 
);

typedef void (CHM_STD_CALL *NETserverOnCloseCallback)
(
   NETuserHandle       UserHandle,
   NETserverHandle     ServerHandle
);

typedef void (CHM_STD_CALL *NETtransportOnConnectCallback)
(
   NETuserHandle UserHandle, 
   NETconnectionHandle TransportId 
);

typedef void (CHM_STD_CALL *NETtransportOnMessageCallback)
( 
   NETuserHandle UserHandle, 
   NETuserHandle ServerUserHandle, 
   NETconnectionHandle TransportId, 
   const char* pMessage 
);

typedef void (CHM_STD_CALL *NETtransportOnMessageSentCallback)
( 
   NETuserHandle UserHandle, 
   NETuserHandle ServerUserHandle, 
   NETconnectionHandle TransportId, 
   const char* pMessage 
);

typedef void (CHM_STD_CALL *NETtransportOnCloseCallback)
( 
   NETuserHandle UserHandle, 
   NETuserHandle ServerUserHandle, 
   NETconnectionHandle TransportId 
);

typedef void (CHM_STD_CALL *NETtransportOnErrorCallback)
( 
    NETuserHandle UserHandle, 
    NETuserHandle ServerUserHandle, 
    NETconnectionHandle TransportId, 
    int ErrorId, 
    const char* pErrorMessage 
);

CHM_DLL_FUNC(NETstop)();
CHM_DLL_FUNC(NETwait)();

CHM_DLL_FUNC(NETserverCreate)
(
   NETuserHandle UserHandle, 
   NETserverHandle* pServerHandle 
);

CHM_DLL_FUNC(NETserverDestroy)
( 
   NETserverHandle ServerHandle,
   NETuserHandle* pUserHandle 
);

CHM_DLL_FUNC(NETserverListen)
( 
    NETserverHandle ServerHandle, 
    CHMuint16 Port 
);

CHM_DLL_FUNC(NETserverStopListening)( NETserverHandle ServerHandle );

CHM_DLL_FUNC(NETserverCloseAllConnections)( NETserverHandle ServerHandle );


CHM_DLL_FUNC(NETtransportCreate)
(
   NETuserHandle UserHandle, 
   NETconnectionHandle* pConnectionHandle 
);

CHM_DLL_FUNC(NETtransportDestroy)
(
   NETconnectionHandle ConnectionHandle,
   NETuserHandle* pUserHandle 
);

CHM_DLL_FUNC(NETtransportConnect)
(
   NETconnectionHandle TransportId,
   const char* pHost, 
   CHMuint16 Port
);

CHM_DLL_FUNC(NETtransportSendMessage)
( 
   NETconnectionHandle TransportId, 
   const char* pMessage 
);

CHM_DLL_FUNC(NETtransportGetIpAddress)
( 
   NETconnectionHandle TransportId, 
   CHMuint32* pIpAddress 
);

CHM_DLL_FUNC(NETtransportIsConnected)
( 
   NETconnectionHandle TransportId,
   CHMuint32*          pIsConnected 
);

CHM_DLL_FUNC(NETtransportGetIpAddressString)
( 
   NETconnectionHandle TransportId, 
   const char** ppIpAddress 
);

CHM_DLL_FUNC(NETtransportGetHostName)
( 
   NETconnectionHandle TransportId, 
   const char** ppHostName 
);

CHM_DLL_FUNC(NETtransportCloseConnection)( NETconnectionHandle TransportId );

CHM_DLL_FUNC(NETtransportHardCloseConnection)( NETconnectionHandle TransportId );

CHM_DLL_FUNC(NETsetServerOnErrorCallback)
( 
   NETserverOnErrorCallback Callback 
);

CHM_DLL_FUNC(NETsetServerOnNewConnectionCallback)
( 
   NETserverOnNewConnectionCallback Callback 
);

CHM_DLL_FUNC(NETsetTransportOnConnectCallback)
( 
   NETtransportOnConnectCallback Callback 
);

CHM_DLL_FUNC(NETsetTransportOnCloseCallback)
( 
   NETtransportOnCloseCallback Callback 
);

CHM_DLL_FUNC(NETsetTransportOnMessageCallback)
( 
   NETtransportOnMessageCallback Callback 
);

CHM_DLL_FUNC(NETsetTransportOnMessageSentCallback)
( 
   NETtransportOnMessageSentCallback Callback 
);

CHM_DLL_FUNC(NETsetTransportOnErrorCallback)
( 
   NETtransportOnErrorCallback Callback 
);

#endif // end of defensive include
