#ifndef __IGC_DESTINATION_H__
#define __IGC_DESTINATION_H__
//--------------------------------------------------------------------------
// Copyright (C) 1997-2009 iNTERFACEWARE Inc. All Rights Reserved.
//
// Class: IGCdestination
//
// Description:
//
// Class interface definition.
//
// This file is automatically generated.
// DO NOT EDIT.
//
// Author: codegen2
// Date:   Thursday, May 28th, 2009 @ 10:15:00 AM
// Revision: $Revision: 1.13 $
//
// Last Edit Date: $Date: 2009-09-23 17:46:53 $
// Source: $Source: /home/cvs/cvsroot/IGC/IGCdestination.h,v $
//--------------------------------------------------------------------------

#include <IGC/IGCminimumInclude.h>
// Predeclared Classes
class IGCdestinationMessageReceivedEventInputs;
class IGCdestinationMessageReceivedEventOutputs;
class IGCdisconnectReason;


#ifndef __IGC_DESTINATION_HANDLE_H__
#define __IGC_DESTINATION_HANDLE_H__
typedef void* IGCdestinationHandle;
#endif


/**
 *  This class is used to implement an Iguana destination plugin. 
 * 
 *  Destination plugins connect to, and receive messages from Iguana To-Plugin 
 * channel components. 
 * 
 *  Messages are sent from Iguana to the IGCdestination plugin through the 
 * IGCdestination#OnMessageReceived event. The plugin must set properties on the 
 * IGCdestinationMessageReceivedEventOutputs object passed to event handler to 
 * communicate the results of message processing back to Iguana. 
 * 
 *  See: 
 * 
 *  http://www.interfaceware.com/manual/plugin_receiving.html 
 * 
 *  for more information. 
 * 
 */
class IGCdestination
{
public:
   /** Constructor */
   IGCdestination();
   
   /** Destructor */
   virtual ~IGCdestination();
   
   /** This method is part of the internal implementation of this class and should not be called. */
   IGCdestinationHandle GetHandle() const { return Handle; }
   
   
   /**
    *  Describes the reason for the plugin's (most recent) disconnection from Iguana. 
    * 
    *  Only valid after the plugin has been disconnected, and before any subsequent 
    * connection attempts. Specifically, only valid within the 
    * IGCdestination#OnDisconnected handler or after the return of a call to 
    * IGCdestination#WaitForDisconnect or IGCdestination#WaitForDisconnectWithTimeout, 
    * and before any subsequent calls to IGCdestination#Connect. 
    * 
    */
   IGCdisconnectReason DisconnectReason() const;
   
   
   /**
    *  Time in milliseconds the plugin will wait to handshake with Iguana while 
    * executing the IGCdestination#Connect operation (default 5000 milliseconds). 
    * 
    *  For a heavily loaded Iguana server running on a slow machine this may need a 
    * higher value than the default value. 
    * 
    * See also the IGCdestination#SetConnectTimeout method.
    * 
    */
   IGCint32 ConnectTimeout() const;
   
   
   /**
    * Set method for ConnectTimeout.
    * 
    * See IGCdestination#ConnectTimeout.
    * 
    * @param Value Value to set ConnectTimeout to.
    */
   void SetConnectTimeout(IGCint32 Value);
   
   
   /**
    *  Enables logging of internal runtime debug information to the specified file. 
    * 
    *  Must be called before any other methods, and may only be called once per 
    * Destination instance. 
    * 
    *  This function should only be used at the request of iNTERFACEWARE Technical 
    * Support. 
    * 
    * @param FileName Name of the file where debug information is to be logged.
    */
   void EnableDebugLogging(const char* FileName);
   
   
   /**
    *  Connects to an Iguana To-Plugin channel component as a destination plugin. 
    * 
    *  Normally this method is called as the plugin starts and is ready to receive 
    * data from Iguana or if Iguana has disconnected from the plugin such as after 
    * returning from IGCdestination#WaitForDisconnect). 
    * 
    *  It may not be called from within an event handler (for example, may not be 
    * called from within the IGCdestination#OnDisconnected handler). 
    * 
    *  If a connection is not established within the timeout period specified by 
    * IGCdestination#ConnectTimeout, an exception will be thrown. The default timeout 
    * period of 5000 milliseconds should suffice for most plugins, and should only be 
    * adjusted if connection timeouts are observed. 
    * 
    *  One common point of confusion with users is the choice of port number for this 
    * call. This must be for the Plugin Communication Server which is typically 6123 
    * rather than say the LLP port for the particular plugin channel. 
    * 
    *  Throws: Function throws an exception upon connection failure or timeout, or if 
    * called from within an event handler. 
    * 
    * @param HostName Iguana machine hostname or IP address (typically 'localhost' if 
    * the plugin and Iguana are running on the same machine).
    * @param PortNumber Iguana Plugin Communication Server port number (typically 
    * 6123).
    * @param ChannelName Iguana channel name.
    */
   void Connect(const char* HostName, IGCint32 PortNumber, const char* ChannelName);
   
   
   /**
    *  Disconnects the plugin from Iguana. 
    * 
    *  Results in IGCdestination#DisconnectReason being set to DueToPlugin. 
    * 
    */
   void Disconnect();
   
   
   /**
    *  Waits until the plugin is disconnected from Iguana. 
    * 
    *  May not be called from within an event handler (for example, may not be called 
    * from within the IGCdestination#OnDisconnected handler). 
    * 
    */
   void WaitForDisconnect();
   
   
   /**
    *  Waits until either the plugin is disconnected from Iguana, or a specified 
    * timeout elapses. 
    * 
    *  May not be called from within an event handler (for example, may not be called 
    * from within the IGCdestination#OnDisconnected handler). 
    * 
    * @param TimeoutInMilliseconds Timeout (in milliseconds) to wait for 
    * disconnection.
    * @return   Returns true if the plugin disconnected from Iguana, or false if the 
    * timeout elapsed before the plugin was disconnected from Iguana.
    */
   IGCboolean WaitForDisconnectWithTimeout(IGCint32 TimeoutInMilliseconds);
   
   
   /**
    *  Event raised upon receipt of a message from Iguana. 
    * 
    *  Exceptions should never be allowed to propagate out of the event handler. Event 
    * handlers should catch and handle all exceptions internally. 
    * 
    * \param Inputs Input data from Iguana.
    * \param Outputs Output data to send back to Iguana.
    */
   virtual void OnMessageReceived(IGCdestinationMessageReceivedEventInputs& Inputs, IGCdestinationMessageReceivedEventOutputs& Outputs)=0;
   
   
   /**
    *  Event raised upon receipt of a resubmission preview message from Iguana. 
    * 
    *  Plugins should simulate the processing that would be performed by the 
    * IGCdestination#OnMessageReceived event handler without causing external side 
    * effects. For example, database changes should not be made for resubmission 
    * preview messages. 
    * 
    *  Exceptions should never be allowed to propagate out of the event handler. Event 
    * handlers should catch and handle all exceptions internally. 
    * 
    * \param Inputs Input data from Iguana.
    * \param Outputs Output data to send back to Iguana.
    */
   virtual void OnResubmissionPreviewMessageReceived(IGCdestinationMessageReceivedEventInputs& Inputs, IGCdestinationMessageReceivedEventOutputs& Outputs)=0;
   
   
   /**
    *  Event raised upon disconnection of the plugin from Iguana. 
    * 
    *  Will not be raised for failed connection attempts. Specifically, will not be 
    * raised if IGCdestination#Connect throws an exception as a result of a connection 
    * failure. 
    * 
    *  Exceptions should never be allowed to propagate out of the event handler. Event 
    * handlers should catch and handle all exceptions internally. 
    * 
    */
   virtual void OnDisconnected()=0;
   
   
private:
   IGCdestination(const IGCdestination& Orig); // Not allowed
   IGCdestination& operator=(const IGCdestination& Orig); // Not allowed
   static void setup();
   IGCdestinationHandle Handle;
};

#endif // end of defensive include
