#ifndef __IGC_SOURCE_H__
#define __IGC_SOURCE_H__
//--------------------------------------------------------------------------
// Copyright (C) 1997-2009 iNTERFACEWARE Inc. All Rights Reserved.
//
// Class: IGCsource
//
// Description:
//
// Class interface definition.
//
// This file is automatically generated.
// DO NOT EDIT.
//
// Author: codegen2
// Date:   Thursday, May 28th, 2009 @ 10:15:00 AM
// Revision: $Revision: 1.11 $
//
// Last Edit Date: $Date: 2009-09-21 14:43:43 $
// Source: $Source: /home/cvs/cvsroot/IGC/IGCsource.h,v $
//--------------------------------------------------------------------------

#include <IGC/IGCminimumInclude.h>
// Predeclared Classes
class IGCsourceMessageRequestedEventInputs;
class IGCsourceMessageRequestedEventOutputs;
class IGCsourceMessageRequestCompletedEventInputs;
class IGCsourceMessageRequestCompletedEventOutputs;
class IGCdisconnectReason;


#ifndef __IGC_SOURCE_HANDLE_H__
#define __IGC_SOURCE_HANDLE_H__
typedef void* IGCsourceHandle;
#endif


/**
 *  This class is used to implement an Iguana source plugin. 
 * 
 *  Source plugins connect to, and send messages to Iguana From-Plugin channel 
 * components. 
 * 
 *  Messages are sent to Iguana using a "polling" or "pull" approach (as opposed to 
 * a "push" approach). Iguana sends a message request to the IGCsource plugin, 
 * raising the IGCsource#OnMessageRequested event. The IGCsource plugin responds 
 * with the next available unacknowledged message. Once Iguana has received and 
 * enqueued the message, a message request completed notification is sent back to 
 * the IGCsource plugin, raising the IGCsource#OnMessageRequestCompleted event. The 
 * IGCsource plugin notes that the message has been acknowledged, and that it can 
 * advance to the next available message. 
 * 
 *  The message polling cycle repeats without delay while messages are available. 
 * Once all available messages have been transferred (indicated by the plugin 
 * responding to a message request with an empty message), the cycle repeats at an 
 * interval determined by the Polling Time configured in the channel's From-Plugin 
 * component. 
 * 
 *  See 
 * 
 *  http://www.interfaceware.com/manual/plugin_sending.html 
 * 
 *  for more information. 
 * 
 */
class IGCsource
{
public:
   /** Constructor */
   IGCsource();
   
   /** Destructor */
   virtual ~IGCsource();
   
   /** This method is part of the internal implementation of this class and should not be called. */
   IGCsourceHandle GetHandle() const { return Handle; }
   
   
   /**
    *  Describes the reason for the plugin's (most recent) disconnection from Iguana. 
    * 
    *  Only valid after the plugin has been disconnected, and before any subsequent 
    * connection attempts. Specifically, only valid within the 
    * IGCsource#OnDisconnected handler or after the return of a call to 
    * IGCsource#WaitForDisconnect or IGCsource#WaitForDisconnectWithTimeout, and 
    * before any subsequent calls to IGCsource#Connect. 
    * 
    */
   IGCdisconnectReason DisconnectReason() const;
   
   
   /**
    *  Time in milliseconds the plugin will wait to handshake with Iguana while 
    * executing the IGCsource#Connect operation (default 5000 milliseconds). 
    * 
    *  For a heavily loaded Iguana server running on a slow machine this may need a 
    * higher value than the default value. 
    * 
    * See also the IGCsource#SetConnectTimeout method.
    * 
    */
   IGCint32 ConnectTimeout() const;
   
   
   /**
    * Set method for ConnectTimeout.
    * 
    * See IGCsource#ConnectTimeout.
    * 
    * @param Value Value to set ConnectTimeout to.
    */
   void SetConnectTimeout(IGCint32 Value);
   
   
   /**
    *  Enables logging of internal runtime debug information to the specified file. 
    * 
    *  Must be called before any other methods, and may only be called once per Source 
    * instance. 
    * 
    *  This function should only be used at the request of iNTERFACEWARE Technical 
    * Support. 
    * 
    * @param FileName Name of the file where debug information is to be logged.
    */
   void EnableDebugLogging(const char* FileName);
   
   
   /**
    *  Connects to an Iguana From-Plugin channel component as a source plugin. 
    * 
    *  Should be called only while the plugin is disconnected (for example, after a 
    * return from IGCsource#WaitForDisconnect). 
    * 
    *  May not be called from within an event handler (for example, may not be called 
    * from within the IGCsource#OnDisconnected handler). 
    * 
    *  If a connection is not established within the timeout period specified by 
    * IGCsource#ConnectTimeout, an exception will be thrown. The default timeout 
    * period of 5000 milliseconds should suffice for most plugins, and should only be 
    * adjusted if connection timeouts are observed. 
    * 
    *  Throws: Function throws an exception upon connection failure or timeout, or if 
    * called from within an event handler. 
    * 
    * @param HostName Iguana machine hostname or IP address (typically 'localhost'     
    *         if the plugin and Iguana are running on the same machine).
    * @param PortNumber Iguana Plugin Communication Server port number (typically 
    * 6123).
    * @param ChannelName Iguana channel name.
    */
   void Connect(const char* HostName, IGCint32 PortNumber, const char* ChannelName);
   
   
   /**
    *  Disconnects the plugin from Iguana. 
    * 
    *  Results in IGCsource#DisconnectReason being set to DueToPlugin. 
    * 
    */
   void Disconnect();
   
   
   /**
    *  Waits until the plugin is disconnected from Iguana. 
    * 
    *  May not be called from within an event handler (for example, may not be called 
    * from within the IGCsource#OnDisconnected handler). 
    * 
    */
   void WaitForDisconnect();
   
   
   /**
    *  Waits until either the plugin is disconnected from Iguana, or a specified 
    * timeout elapses. 
    * 
    *  May not be called from within an event handler (for example, may not be called 
    * from within the IGCsource#OnDisconnected handler). 
    * 
    * @param TimeoutInMilliseconds Timeout (in milliseconds) to wait for 
    * disconnection.
    * @return   Returns true if the plugin disconnected from Iguana.  Returns false if 
    * the timeout elapsed before the plugin was disconnected from Iguana. 
    */
   IGCboolean WaitForDisconnectWithTimeout(IGCint32 TimeoutInMilliseconds);
   
   
   /**
    *  Event raised upon reciept of a message request from Iguana. 
    * 
    *  The plugin should respond with either the next available unacknowledged 
    * message, or an empty message if no messages are available. 
    * 
    *  Exceptions should never be allowed to propagate out of the event handler. Event 
    * handlers should catch and handle all exceptions internally. 
    * 
    * \param Inputs Input data from Iguana.
    * \param Outputs Output data to send back to Iguana.
    */
   virtual void OnMessageRequested(IGCsourceMessageRequestedEventInputs& Inputs, IGCsourceMessageRequestedEventOutputs& Outputs)=0;
   
   
   /**
    *  Event raised upon receipt of a message request completed notification from 
    * Iguana. 
    * 
    *  Exceptions should never be allowed to propagate out of the event handler. Event 
    * handlers should catch and handle all exceptions internally. 
    * 
    * \param Inputs Input data from Iguana.
    * \param Outputs Output data to send back to Iguana.
    */
   virtual void OnMessageRequestCompleted(IGCsourceMessageRequestCompletedEventInputs& Inputs, IGCsourceMessageRequestCompletedEventOutputs& Outputs)=0;
   
   
   /**
    *  Event raised upon disconnection of the plugin from Iguana. 
    * 
    *  Will not be raised for failed connection attempts. Specifically, will not be 
    * raised if IGCsource#Connect throws an exception as a result of a connection 
    * failure. 
    * 
    *  Exceptions should never be allowed to propagate out of the event handler. Event 
    * handlers should catch and handle all exceptions internally. 
    * 
    */
   virtual void OnDisconnected()=0;
   
   
private:
   IGCsource(const IGCsource& Orig); // Not allowed
   IGCsource& operator=(const IGCsource& Orig); // Not allowed
   static void setup();
   IGCsourceHandle Handle;
};

#endif // end of defensive include
